@@ -58,11 +58,11 @@ def read_excel_xlsx(path, sheet_name):
         print()
 
 
-def read_excel(path: str, sheet: str = "Sheet1", encoding="utf-8", del_file=False):
+def read_excel(path: str, sheet: str = None, encoding="utf-8", del_file=False):
     """
     读取文件
     :param path:  文件路径
-    :param sheet:  有sheet页的需要指定sheet名字
+    :param sheet:  有sheet页的需要指定sheet名字,不指定默认第一个sheet
     :param encoding:  编码格式
     :param del_file:  读取完成后是否删除文件，默认不删除
     :return:
@@ -74,12 +74,16 @@ def read_excel(path: str, sheet: str = "Sheet1", encoding="utf-8", del_file=Fals
     else:
         try:
             workbook = op.load_workbook(path)
+            if not sheet:
+                sheet = workbook.sheetnames[0]
             sheet = workbook[sheet]  # 获取表单
             max_row = sheet.max_row  # 获取最大行数
             max_column = sheet.max_column  # 获取最大列数
             lr = tuple([tuple([sheet.cell(row=row, column=column).value for column in range(1, max_column+1)]) for row in range(1, max_row+1)])
         except XLRDError:
             workbook = xlrd.open_workbook(path)  # 打开工作簿
+            if not sheet:
+                sheet = workbook.sheet_names()[0]
             sheet = workbook.sheet_by_name(sheet_name=sheet)  # 获取表单
             max_row = sheet.nrows  # 获取最大行
             max_column = sheet.ncols  # 获取最大列数
